==> activemq-runtime-config-5.19.0-20230329.202229-1-sources.jar: org/apache/activemq/schema/core/DtoClientIdFilterDispatchPolicy.java <==

package org.apache.activemq.schema.core;

import java.util.HashMap;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import javax.xml.namespace.QName;
import org.apache.activemq.plugin.jaxb2_commons.ElementAwareEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.Equals2;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy2;
import org.jvnet.jaxb2_commons.lang.HashCode2;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy2;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="ptpClientId" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="ptpSuffix" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="id" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "clientIdFilterDispatchPolicy")
public class DtoClientIdFilterDispatchPolicy implements Equals2, HashCode2, ToString2
{

    @XmlAttribute(name = "ptpClientId")
    protected String ptpClientId;
    @XmlAttribute(name = "ptpSuffix")
    protected String ptpSuffix;
    @XmlAttribute(name = "id")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the ptpClientId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPtpClientId() {
        return ptpClientId;
    }

    /**
     * Sets the value of the ptpClientId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPtpClientId(String value) {
        this.ptpClientId = value;
    }

    /**
     * Gets the value of the ptpSuffix property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPtpSuffix() {
        return ptpSuffix;
    }

    /**
     * Sets the value of the ptpSuffix property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPtpSuffix(String value) {
        this.ptpSuffix = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            String thePtpClientId;
            thePtpClientId = this.getPtpClientId();
            strategy.appendField(locator, this, "ptpClientId", buffer, thePtpClientId, (this.ptpClientId!= null));
        }
        {
            String thePtpSuffix;
            thePtpSuffix = this.getPtpSuffix();
            strategy.appendField(locator, this, "ptpSuffix", buffer, thePtpSuffix, (this.ptpSuffix!= null));
        }
        {
            String theId;
            theId = this.getId();
            strategy.appendField(locator, this, "id", buffer, theId, (this.id!= null));
        }
        return buffer;
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy2 strategy) {
        int currentHashCode = 1;
        {
            String thePtpClientId;
            thePtpClientId = this.getPtpClientId();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "ptpClientId", thePtpClientId), currentHashCode, thePtpClientId, (this.ptpClientId!= null));
        }
        {
            String thePtpSuffix;
            thePtpSuffix = this.getPtpSuffix();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "ptpSuffix", thePtpSuffix), currentHashCode, thePtpSuffix, (this.ptpSuffix!= null));
        }
        {
            String theId;
            theId = this.getId();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "id", theId), currentHashCode, theId, (this.id!= null));
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy2 strategy = JAXBHashCodeStrategy.INSTANCE2;
        return this.hashCode(null, strategy);
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy2 strategy) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final DtoClientIdFilterDispatchPolicy that = ((DtoClientIdFilterDispatchPolicy) object);
        {
            String lhsPtpClientId;
            lhsPtpClientId = this.getPtpClientId();
            String rhsPtpClientId;
            rhsPtpClientId = that.getPtpClientId();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "ptpClientId", lhsPtpClientId), LocatorUtils.property(thatLocator, "ptpClientId", rhsPtpClientId), lhsPtpClientId, rhsPtpClientId, (this.ptpClientId!= null), (that.ptpClientId!= null))) {
                return false;
            }
        }
        {
            String lhsPtpSuffix;
            lhsPtpSuffix = this.getPtpSuffix();
            String rhsPtpSuffix;
            rhsPtpSuffix = that.getPtpSuffix();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "ptpSuffix", lhsPtpSuffix), LocatorUtils.property(thatLocator, "ptpSuffix", rhsPtpSuffix), lhsPtpSuffix, rhsPtpSuffix, (this.ptpSuffix!= null), (that.ptpSuffix!= null))) {
                return false;
            }
        }
        {
            String lhsId;
            lhsId = this.getId();
            String rhsId;
            rhsId = that.getId();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "id", lhsId), LocatorUtils.property(thatLocator, "id", rhsId), lhsId, rhsId, (this.id!= null), (that.id!= null))) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy2 strategy = ElementAwareEqualsStrategy.INSTANCE2;
        return equals(null, null, object, strategy);
    }

}

==> activemq-runtime-config-6.1.6-sources.jar: org/apache/activemq/schema/core/DtoClientIdFilterDispatchPolicy.java <==

package org.apache.activemq.schema.core;

import java.util.HashMap;
import java.util.Map;
import javax.xml.namespace.QName;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAnyAttribute;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.apache.activemq.plugin.jaxb2_commons.ElementAwareEqualsStrategy;
import org.jvnet.jaxb.lang.Equals;
import org.jvnet.jaxb.lang.EqualsStrategy;
import org.jvnet.jaxb.lang.HashCode;
import org.jvnet.jaxb.lang.HashCodeStrategy;
import org.jvnet.jaxb.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb.lang.JAXBToStringStrategy;
import org.jvnet.jaxb.lang.ToString;
import org.jvnet.jaxb.lang.ToStringStrategy;
import org.jvnet.jaxb.locator.ObjectLocator;
import org.jvnet.jaxb.locator.util.LocatorUtils;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="ptpClientId" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="ptpSuffix" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="id" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "clientIdFilterDispatchPolicy")
public class DtoClientIdFilterDispatchPolicy implements Equals, HashCode, ToString
{

    @XmlAttribute(name = "ptpClientId")
    protected String ptpClientId;
    @XmlAttribute(name = "ptpSuffix")
    protected String ptpSuffix;
    @XmlAttribute(name = "id")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Obtient la valeur de la propriété ptpClientId.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPtpClientId() {
        return ptpClientId;
    }

    /**
     * Définit la valeur de la propriété ptpClientId.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPtpClientId(String value) {
        this.ptpClientId = value;
    }

    /**
     * Obtient la valeur de la propriété ptpSuffix.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPtpSuffix() {
        return ptpSuffix;
    }

    /**
     * Définit la valeur de la propriété ptpSuffix.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPtpSuffix(String value) {
        this.ptpSuffix = value;
    }

    /**
     * Obtient la valeur de la propriété id.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Définit la valeur de la propriété id.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    @Override
    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.getInstance();
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    @Override
    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    @Override
    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        {
            String thePtpClientId;
            thePtpClientId = this.getPtpClientId();
            strategy.appendField(locator, this, "ptpClientId", buffer, thePtpClientId, (this.ptpClientId!= null));
        }
        {
            String thePtpSuffix;
            thePtpSuffix = this.getPtpSuffix();
            strategy.appendField(locator, this, "ptpSuffix", buffer, thePtpSuffix, (this.ptpSuffix!= null));
        }
        {
            String theId;
            theId = this.getId();
            strategy.appendField(locator, this, "id", buffer, theId, (this.id!= null));
        }
        return buffer;
    }

    @Override
    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = 1;
        {
            String thePtpClientId;
            thePtpClientId = this.getPtpClientId();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "ptpClientId", thePtpClientId), currentHashCode, thePtpClientId, (this.ptpClientId!= null));
        }
        {
            String thePtpSuffix;
            thePtpSuffix = this.getPtpSuffix();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "ptpSuffix", thePtpSuffix), currentHashCode, thePtpSuffix, (this.ptpSuffix!= null));
        }
        {
            String theId;
            theId = this.getId();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "id", theId), currentHashCode, theId, (this.id!= null));
        }
        return currentHashCode;
    }

    @Override
    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.getInstance();
        return this.hashCode(null, strategy);
    }

    @Override
    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final DtoClientIdFilterDispatchPolicy that = ((DtoClientIdFilterDispatchPolicy) object);
        {
            String lhsPtpClientId;
            lhsPtpClientId = this.getPtpClientId();
            String rhsPtpClientId;
            rhsPtpClientId = that.getPtpClientId();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "ptpClientId", lhsPtpClientId), LocatorUtils.property(thatLocator, "ptpClientId", rhsPtpClientId), lhsPtpClientId, rhsPtpClientId, (this.ptpClientId!= null), (that.ptpClientId!= null))) {
                return false;
            }
        }
        {
            String lhsPtpSuffix;
            lhsPtpSuffix = this.getPtpSuffix();
            String rhsPtpSuffix;
            rhsPtpSuffix = that.getPtpSuffix();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "ptpSuffix", lhsPtpSuffix), LocatorUtils.property(thatLocator, "ptpSuffix", rhsPtpSuffix), lhsPtpSuffix, rhsPtpSuffix, (this.ptpSuffix!= null), (that.ptpSuffix!= null))) {
                return false;
            }
        }
        {
            String lhsId;
            lhsId = this.getId();
            String rhsId;
            rhsId = that.getId();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "id", lhsId), LocatorUtils.property(thatLocator, "id", rhsId), lhsId, rhsId, (this.id!= null), (that.id!= null))) {
                return false;
            }
        }
        return true;
    }

    @Override
    public boolean equals(Object object) {
        final EqualsStrategy strategy = new ElementAwareEqualsStrategy();
        return equals(null, null, object, strategy);
    }

}
